/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <vdr/device.h>

#include "menu.h"
#include "config.h"


#define MAX_TIMEOUT 50000

static const char* const devices[] = { "Auto", "1", "2", "3", "4", "5", "6", "7", "8" };


//////////////////////////////////////////////////////////////////////////////


NAScanSetupMenu::NAScanSetupMenu(void)
{
  newAdapter = config.adapter;
  newIgnoreNoStream = config.ignoreNoStream;
  newUseNetworkName = config.useNetworkName;

  newTuningTimeout = config.tuningTimeout;
  newInitialTuningTimeout = config.initialTuningTimeout;
  newSdtTimeout = config.sdtTimeout;
  newPmtTimeout = config.pmtTimeout;
  newNitTimeout = config.nitTimeout;
  
  Add(new cMenuEditStraItem("Scan with DVB device number", &newAdapter, min(9, cDevice::NumDevices()+1), devices));
  Add(new cMenuEditBoolItem("Ignore channels with no stream info", &newIgnoreNoStream));
  Add(new cMenuEditBoolItem("Use network name", &newUseNetworkName));
  
  Add(new cMenuEditIntItem("Initial tuning timeout (ms)", &newInitialTuningTimeout, 100, MAX_TIMEOUT));
  Add(new cMenuEditIntItem("Tuning timeout (ms)", &newTuningTimeout, 100, MAX_TIMEOUT));
  Add(new cMenuEditIntItem("SDT timeout (ms)", &newSdtTimeout, 0, MAX_TIMEOUT));
  Add(new cMenuEditIntItem("NIT timeout (ms)", &newNitTimeout, 0, MAX_TIMEOUT));
  Add(new cMenuEditIntItem("PMT timeout (ms)", &newPmtTimeout, 0, MAX_TIMEOUT));
}


//----------------------------------------------------------------------------

void NAScanSetupMenu::Store(void)
{
  SetupStore("adapter",        config.adapter        = newAdapter);
  SetupStore("ignoreNoStream", config.ignoreNoStream = newIgnoreNoStream);
  SetupStore("useNetworkName", config.useNetworkName = newUseNetworkName);
  
  SetupStore("tuningTimeout", config.tuningTimeout = newTuningTimeout);
  SetupStore("initialTuningTimeout", config.initialTuningTimeout = newInitialTuningTimeout);
  SetupStore("sdtTimeout", config.sdtTimeout = newSdtTimeout);
  SetupStore("pmtTimeout", config.pmtTimeout = newPmtTimeout);
  SetupStore("nitTimeout", config.nitTimeout = newNitTimeout);
}


//////////////////////////////////////////////////////////////////////////////



