/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <vdr/plugin.h>

#include "osd.h"
#include "menu.h"
#include "tools.h"
#include "config.h"


//////////////////////////////////////////////////////////////////////////////


static const char *VERSION        = "0.0.2";
static const char *DESCRIPTION    = "North American Channel Scanner";
static const char *MAINMENUENTRY  = "NA Scan";


NascanConfig config;


//////////////////////////////////////////////////////////////////////////////


class cPluginNascan : public cPlugin {
private:
  // Add any member variables or functions you may need here.
public:
  cPluginNascan(void);
  virtual ~cPluginNascan();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return DESCRIPTION; }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Stop(void);
  virtual void Housekeeping(void);
  virtual void MainThreadHook(void);
  virtual cString Active(void);
  virtual time_t WakeupTime(void);
  virtual const char *MainMenuEntry(void) { return MAINMENUENTRY; }
  virtual cOsdObject *MainMenuAction(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  virtual bool Service(const char *Id, void *Data = NULL);
  virtual const char **SVDRPHelpPages(void);
  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
  };


//////////////////////////////////////////////////////////////////////////////


cPluginNascan::cPluginNascan(void)
{
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
  SetLogType(L_ERR | L_MSG);
  
  config.adapter = 0; // Auto
  config.ignoreNoStream = false;
  config.useNetworkName = true;
  
  config.tuningTimeout = 2000;
  config.initialTuningTimeout = 10000;
  config.sdtTimeout = 10000;
  config.pmtTimeout = 10000;
  config.nitTimeout = 10000;
}

cPluginNascan::~cPluginNascan()
{
  // Clean up after yourself!
}

const char *cPluginNascan::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginNascan::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginNascan::Initialize(void)
{
  // Initialize any background activities the plugin shall perform.
  return true;
}

bool cPluginNascan::Start(void)
{
  // Start any background activities the plugin shall perform.
  return true;
}

void cPluginNascan::Stop(void)
{
  // Stop any background activities the plugin is performing.
}

void cPluginNascan::Housekeeping(void)
{
  // Perform any cleanup or other regular tasks.
}

void cPluginNascan::MainThreadHook(void)
{
  // Perform actions in the context of the main program thread.
  // WARNING: Use with great care - see PLUGINS.html!
}

cString cPluginNascan::Active(void)
{
  // Return a message string if shutdown should be postponed
  return NULL;
}

time_t cPluginNascan::WakeupTime(void)
{
  // Return custom wakeup time for shutdown script
  return 0;
}

cOsdObject *cPluginNascan::MainMenuAction(void)
{
  // Perform the action when selected from the main VDR menu.
  return new ScanOsd;
}

cMenuSetupPage *cPluginNascan::SetupMenu(void)
{
  // Return a setup menu in case the plugin supports one.
  return new NAScanSetupMenu;
}

bool cPluginNascan::SetupParse(const char *Name, const char *Value)
{
  // Parse your own setup parameters and store their values.
  if      (!strcasecmp(Name, "adapter"))        config.adapter        = atoi(Value);
  else if (!strcasecmp(Name, "ignoreNoStream")) config.ignoreNoStream = atoi(Value);
  else if (!strcasecmp(Name, "useNetworkName")) config.useNetworkName = atoi(Value);
  else if (!strcasecmp(Name, "tuningTimeout")) config.tuningTimeout = atoi(Value);
  else if (!strcasecmp(Name, "initialTuningTimeout")) config.initialTuningTimeout = atoi(Value);
  else if (!strcasecmp(Name, "sdtTimeout")) config.sdtTimeout = atoi(Value);
  else if (!strcasecmp(Name, "pmtTimeout")) config.pmtTimeout = atoi(Value);
  else if (!strcasecmp(Name, "nitTimeout")) config.nitTimeout = atoi(Value);
  else
    return false;
     
  return true;
}

bool cPluginNascan::Service(const char *Id, void *Data)
{
  // Handle custom service requests from other plugins
  return false;
}

const char **cPluginNascan::SVDRPHelpPages(void)
{
  // Return help text for SVDRP commands this plugin implements
  return NULL;
}

cString cPluginNascan::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
{
  // Process SVDRP commands this plugin implements
  return NULL;
}


//////////////////////////////////////////////////////////////////////////////


VDRPLUGINCREATOR(cPluginNascan); // Don't touch this!


//////////////////////////////////////////////////////////////////////////////


