/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef __NASCAN_PMT_FILTER_H
#define __NASCAN_PMT_FILTER_H


#include <list>

#include <vdr/device.h>
#include <vdr/tools.h>

#include "filter.h"
#include "blacklist.h"


//////////////////////////////////////////////////////////////////////////////


class ChannelSorter : public cListObject 
{
public:
  cChannel* channel;

  ChannelSorter(cChannel* Channel) { channel = Channel; }
  virtual ~ChannelSorter() { delete channel; }
  
  virtual int Compare(const cListObject &ListObject) const 
  {
    ChannelSorter* cs = (ChannelSorter*) &ListObject;
    //return (channel->Number() - cs->channel->Number());
    return (channel->Sid() - cs->channel->Sid());
  }
};


//////////////////////////////////////////////////////////////////////////////


class PmtFilter : public GFilter
{
public:
  PmtFilter(cList<ChannelSorter>* cl);
  virtual ~PmtFilter();
  
  bool GotPAT(void) { return gotPat;  } const
  int  GotPMT(void) { return gotPmts; } const
  
  void SetTransponder(const cChannel* t) { curTransponder = t; }
  
protected:
  virtual void Process(u_short pid, u_char tid, const u_char* data, int length); 
  virtual void SetStatus(bool On);
    
private:  
  bool ProcessPAT(const uint8_t* data);
  bool ProcessPMT(const uint8_t* data);
  
  int source, transponder;
  
  bool gotPat;
  int gotPmts;

  std::list<uint16_t> pmtSids;
  int numPmtSids;
  int pmtSidIndex;
  
  const cChannel* curTransponder;
  
  cList<ChannelSorter>* channelList;
  Blacklist blacklist;
};


//////////////////////////////////////////////////////////////////////////////


#endif //__NASCAN_PMT_FILTER_H

